@@ -26,21 +26,21 @@ def create_env(env_config: dict = None) -> gym.Env:
 
     if not env_config:
         env_config = {
-            "energym_environment": "MixedUseFanFCU-v0",
+            "name": "MixedUseFanFCU-v0",
             "weather": "GRC_A_Athens",
             "days": 365,
             "gym_kwargs": {
                 "max_episode_length": 35040,
                 "step_period": 15,
                 "normalize": True,
-                "discretize": 30,
+                "discretize": False,  # if not False, add number
                 "ignore_reset": False,
             },
         }
 
     # build energym environment
     env = energym.make(
-        env_config["energym_environment"],
+        env_config["name"],
         weather=env_config["weather"],
         simulation_days=env_config["days"],
     )
