@@ -31,7 +31,17 @@ def log_subprocess(pipe, process_name="subprocess"):
 
     Color setting of context is described in https://stackoverflow.com/a/33206814.
     """
-    for line in iter(pipe.readline, b""):  # b'\n'-separated lines
+    lines = []
+    max_len = 1000
+
+    for i, line in enumerate(iter(pipe.readline, b"")):  # b'\n'-separated lines
         context = f"\033[34m{process_name}:\033[0m"  # .decode("ascii")
         line = line.decode("utf-8").rstrip()
         logger.info(f"{context} {line}")
+        if i < max_len:
+            lines.append(line)
+        else:
+            lines = lines[1:].append(line)
+
+    output = "\n".join(lines)
+    return output
